==> WheelPicker-3.0.2-sources.jar: com/github/gzuliyujiang/wheelpicker/widget/CarNumberWheelLayout.java <==
/*
 * Copyright (c) 2016-present 贵州纳雍穿青人李裕江<1032694760@qq.com>
 *
 * The software is licensed under the Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *     http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND, EITHER EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT, MERCHANTABILITY OR FIT FOR A PARTICULAR
 * PURPOSE.
 * See the Mulan PSL v2 for more details.
 */

package com.github.gzuliyujiang.wheelpicker.widget;

import android.content.Context;
import android.util.AttributeSet;

import androidx.annotation.NonNull;

import com.github.gzuliyujiang.wheelpicker.impl.CarNumberProvider;

/**
 * @author 贵州山野羡民（1032694760@qq.com）
 * @since 2021/6/9 11:57
 */
public class CarNumberWheelLayout extends LinkageWheelLayout {

    public CarNumberWheelLayout(Context context) {
        super(context);
    }

    public CarNumberWheelLayout(Context context, AttributeSet attrs) {
        super(context, attrs);
    }

    public CarNumberWheelLayout(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
    }

    public CarNumberWheelLayout(Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
    }

    @Override
    protected void onInit(@NonNull Context context) {
        super.onInit(context);
        setData(new CarNumberProvider());
    }

}

==> WheelPicker-4.0.0-sources.jar: com/github/gzuliyujiang/wheelpicker/widget/CarNumberWheelLayout.java <==
/*
 * Copyright (c) 2016-present 贵州纳雍穿青人李裕江<1032694760@qq.com>
 *
 * The software is licensed under the Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *     http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND, EITHER EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT, MERCHANTABILITY OR FIT FOR A PARTICULAR
 * PURPOSE.
 * See the Mulan PSL v2 for more details.
 */

package com.github.gzuliyujiang.wheelpicker.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.util.AttributeSet;

import androidx.annotation.NonNull;

import com.github.gzuliyujiang.wheelpicker.impl.CarNumberProvider;

/**
 * @author 贵州山野羡民（1032694760@qq.com）
 * @since 2021/6/9 11:57
 */
public class CarNumberWheelLayout extends LinkageWheelLayout {
    private CarNumberProvider provider;

    public CarNumberWheelLayout(Context context) {
        super(context);
    }

    public CarNumberWheelLayout(Context context, AttributeSet attrs) {
        super(context, attrs);
    }

    public CarNumberWheelLayout(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
    }

    public CarNumberWheelLayout(Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
    }

    @Override
    protected void onInit(@NonNull Context context) {
        super.onInit(context);
        provider = new CarNumberProvider();
        setData(provider);
    }

    @Override
    protected void onAttributeSet(@NonNull Context context, @NonNull TypedArray typedArray) {
        super.onAttributeSet(context, typedArray);
        setFirstVisible(provider.firstLevelVisible());
        setThirdVisible(provider.thirdLevelVisible());
    }

}
